@@ -63,7 +63,7 @@ def _get_expr_string(expr: ast.expr) -> str:
     return expr_str
 
 
-@lru_cache(maxsize=128)
+@lru_cache(maxsize=128, typed=True)
 def eval_value(value):
     """
     Uses `ast.literal_eval` to parse strings into an appropriate Python primative.
@@ -88,7 +88,7 @@ def eval_value(value):
     return value
 
 
-@lru_cache(maxsize=128)
+@lru_cache(maxsize=128, typed=True)
 def parse_kwarg(kwarg: str, raise_if_unparseable=False) -> Dict[str, Any]:
     """
     Parses a potential kwarg as a string into a dictionary.
@@ -129,7 +129,7 @@ def parse_kwarg(kwarg: str, raise_if_unparseable=False) -> Dict[str, Any]:
         raise InvalidKwarg(f"'{kwarg}' could not be parsed")
 
 
-@lru_cache(maxsize=128)
+@lru_cache(maxsize=128, typed=True)
 def parse_call_method_name(call_method_name: str) -> Tuple[str, List[Any]]:
     """
     Parses the method name from the request payload into a set of parameters to pass to a method.
